@@ -10,15 +10,15 @@ use Catalyst::Authentication::User::AuthTkt;
 
 __PACKAGE__->mk_accessors(qw( cookie_name aat config debug ));
 
-our $VERSION = '0.11_01';
+our $VERSION = '0.03';
 
 =head1 NAME
 
-Catalyst::Authentication::Store::AuthTkt - shim for Apache::AuthTkt
+Catalyst::Authentication::AuthTkt - shim for Apache::AuthTkt
 
 =head1 DESCRIPTION
 
-This module implements the Catalyst::Plugin::Authentication API for Apache::AuthTkt.
+This module implements the Catalyst::Authentication API for Apache::AuthTkt.
 See Catalyst::Authentication::AuthTkt for complete user documentation.
 
 =head1 METHODS
@@ -36,19 +36,11 @@ sub new {
     my ( $class, $config, $app ) = @_;
     my $self = $class->SUPER::new(
         { cookie_name => $config->{cookie_name} || 'auth_tkt' } );
-    my @aat_args = ();
-    for my $param (qw( cookie_name domain timeout timeout_refresh )) {
-        if ( exists $config->{$param} ) {
-            push( @aat_args, $param => $config->{$param} );
-        }
-    }
     if ( $config->{conf} ) {
-        $self->{aat}
-            = Apache::AuthTkt->new( conf => $config->{conf}, @aat_args );
+        $self->{aat} = Apache::AuthTkt->new( conf => $config->{conf} );
     }
     elsif ( $config->{secret} ) {
-        $self->{aat}
-            = Apache::AuthTkt->new( secret => $config->{secret}, @aat_args );
+        $self->{aat} = Apache::AuthTkt->new( secret => $config->{secret} );
     }
     else {
         croak "conf or secret configuration required";
@@ -85,9 +77,6 @@ find_user() checks the I<context> request object for a cookie named cookie_name(
 or a param named cookie_name(), in that order. If neither are present, or if
 present but invalid, find_user() returns undef.
 
-See also the 'mock' feature as per the
-example in Catalyst::Authentication::AuthTkt SYNOPSIS.
-
 =cut
 
 sub find_user {
@@ -95,24 +84,6 @@ sub find_user {
 
     $c->log->debug('AuthTkt: authenticating request') if $self->debug;
 
-    # mock feature for development when you just want to mimic cookie
-    # (e.g., when running under localhost or different domain than
-    # your auth server)
-    if ( $self->config->{mock} ) {
-        my %user = %{ $self->config->{mock} };
-
-        $c->log->debug("AuthTkt: using mock user $user{id}") if $self->debug;
-
-        return Catalyst::Authentication::User::AuthTkt->new(
-            {   id     => $user{id},
-                data   => '',
-                ts     => '',
-                tokens => $user{tokens},
-                ticket => 'mock_auth_cookie',
-            }
-        );
-    }
-
     # if no cookie or param, return undef
     my $cookie = $c->req->cookie( $self->cookie_name )
         || $c->req->params->{ $self->cookie_name };
@@ -120,19 +91,11 @@ sub find_user {
         $c->log->debug(
             "AuthTkt: No cookie or param for " . $self->cookie_name )
             if $self->debug;
-        $c->logout;    # in case user was in session
         return;
     }
 
     # unpack cookie
     my $t = ref($cookie) ? $cookie->value : $cookie;
-    if ( !defined $t or !length $t ) {
-        $c->log->debug(
-            "AuthTkt: no ticket value in cookie " . $self->cookie_name )
-            if $self->debug;
-        $c->logout;    # in case user was in session
-        return;
-    }
     $c->log->debug("AuthTkt: $t") if $self->debug;
 
 # running under fcgi (others?) the REMOTE_ADDR env var is not set, which Apache::AuthTkt
@@ -140,14 +103,11 @@ sub find_user {
 # So we set it explicitly here.
 # if the 'ignore_ip' config option were used consistently (i.e. both setting and checking)
 # then this hack would not be necessary, but we can't vouch for how the ticket was set.
-    if (   !exists $ENV{REMOTE_ADDR}
-        or $self->config->{use_req_address}
-        or $ENV{REMOTE_ADDR} ne $c->req->address )
-    {
-        my $ipaddr = $self->config->{use_req_address} || $c->req->address;
-        $c->log->debug("setting REMOTE_ADDR to $ipaddr")
+    if ( !exists $ENV{REMOTE_ADDR} or $self->config->{use_req_address} ) {
+        $c->log->debug( "setting REMOTE_ADDR to " . $c->req->address )
             if $self->debug;
-        $self->aat->{ip_addr} = $ipaddr;
+        $self->aat->{ip_addr} = $self->config->{use_req_address}
+            || $c->req->address;
     }
 
     my $ticket = $self->aat->validate_ticket($t);
@@ -157,12 +117,11 @@ sub find_user {
         $c->log->debug( "AuthTkt: parsed ticket looks like: "
                 . dump( $self->aat->parse_ticket($t) ) )
             if $self->debug;
-        $c->logout;    # in case user was in session
         return;
     }
 
     if ( $self->ticket_expired( $c, $ticket ) ) {
-        $c->logout;    # in case user was in session
+        $c->logout;
         return;
     }
 
@@ -256,7 +215,7 @@ sub renew_ticket {
             : '/',
             domain => defined $existing_cookie->domain
             ? $existing_cookie->domain
-            : $authtkt->domain
+            : ( $self->config->{domain} || $c->req->host ),
         };
         $c->log->debug( 'AuthTkt: new cookie: '
                 . dump( $c->response->cookies->{ $self->cookie_name } ) )
@@ -279,14 +238,10 @@ sub expire_ticket {
     my ( $self, $c ) = @_;
     my $cookie_name     = $self->cookie_name;
     my $existing_cookie = $c->req->cookie($cookie_name);
-    if ( !$existing_cookie ) {
-        $c->log->warn("no cookie with name $cookie_name found to expire");
-        return;
-    }
     $existing_cookie->value( [] );
     $existing_cookie->expires( time - 100 );
-    $existing_cookie->domain( $self->aat->domain )
-        if $self->aat->domain;
+    $existing_cookie->domain( $self->config->{domain} )
+        if $self->config->{domain};
     $c->res->cookies->{$cookie_name} = $existing_cookie;
     $c->log->debug( "AuthTkt: cookie reset as " . dump($existing_cookie) )
         if $self->debug;
